==> workbench_approver-1.0.0.tar.gz: workbench_approver/src/Entity/ApproverInterface.php <==
<?php

namespace Drupal\workbench_approver\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\user\EntityOwnerInterface;

/**
 * An interface for the Workbench approver entity.
 *
 * Workbench approver entities track required reviewers before content may
 * transition to a new state.
 *
 * Note also that the word 'status' is used for approvals, since the
 * word 'state' is reserved for workflows.
 */
interface ApproverInterface extends ContentEntityInterface, EntityOwnerInterface {

  /**
   * Denotes an approval request was removed by an admin.
   */
  const APPROVAL_RESCINDED = 0;

  /**
   * Denotes an approval request has been invalidated.
   *
   * This state can occur due to the rejection of the revision
   * by another approver.
   */
  const APPROVAL_INVALIDATED = 1;

  /**
   * Denotes an approval request has been outdated.
   *
   * This state can occur due to a revision on the parent node.
   */
  const APPROVAL_OUTDATED = 2;

  /**
   * Denotes an approval request has not been fulfilled.
   */
  const APPROVAL_PENDING = 10;

  /**
   * Denotes an approval request has been granted.
   */
  const APPROVAL_GRANTED = 11;

  /**
   * Denotes an approval request has been rejected.
   */
  const APPROVAL_REJECTED = 12;

  /**
   * Mapping array of approval statuses.
   *
   * @todo This might move to the manager service.
   * If it does, so will statusName() and statusValue().
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup[]
   *   An array of statuses, key by integer value, with
   *   translatable markup as values.
   */
  public static function statusList(): array;

  /**
   * Return the human-readable string for a status name.
   *
   * Note that this is a generic lookup, not tied to an
   * entity. For an entity value, use getStatusName().
   *
   * @param int $status
   *   The status value.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The translatable name of the status.
   */
  public static function statusName(int $status): TranslatableMarkup;

  /**
   * Return the storage value for a status name.
   *
   * Note that this is a generic lookup, not tied to an
   * entity. For an entity value, use getStatus().
   *
   * @param string $status
   *   The human-readable name of the status (untranslated).
   *
   * @return int
   *   The status value.
   */
  public static function statusValue(string $status): int;

  /**
   * Get the status of an approval.
   *
   * @return int
   *   The status value.
   */
  public function getStatus(): int;

  /**
   * Get the human-readable status of an approval.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The translated human-readable status value.
   */
  public function getStatusName(): TranslatableMarkup;

  /**
   * Indicates that an approver has a "blocking" status.
   *
   * A blocking approval request is defined as:
   *
   * - ApproverInterface::isRequired() === TRUE
   *
   * AND one of the following:
   * - ApproverInterface::getStatus() === ApproverInterface::APPROVAL_PENDING
   * - ApproverInterface::getStatus() === ApproverInterface::APPROVAL_REJECTED
   *
   * @return bool
   *   Indicates blocking or non-blocking status.
   */
  public function isBlocking(): bool;

  /**
   * Indicates that an approval request has a "pending" status.
   *
   * A pending approval request is defined as:
   *
   * - ApproverInterface::getStatus() === ApproverInterface::APPROVAL_PENDING
   *
   * @return bool
   *   Indicates pending or not pending status.
   */
  public function isPending(): bool;

  /**
   * Indicates that an approval request has a "rejected" status.
   *
   * A rejected approval request is defined as:
   *
   * - ApproverInterface::getStatus() === ApproverInterface::APPROVAL_REJECTED
   *
   * @return bool
   *   Indicates rejected or not rejected status.
   */
  public function isRejected(): bool;

  /**
   * Indicates if the approval is required or not required.
   *
   * It can also be called blocking (required) or non-blocking (not required).
   *
   * @return bool
   *   Indicates required or not required request.
   */
  public function isRequired(): bool;

  /**
   * Requests can be Active or Inactive.
   *
   * When a request is active, it will have a value equal or greater than 10.
   * When a request is inactive, it will have a value lower than 10.
   * 10 corresponds to APPROVAL_PENDING value.
   *
   * @return bool
   *   Indicated if the approval request is active or inactive.
   */
  public function isActive(): bool;

  /**
   * Gets the approver UID from the request.
   *
   * @return int
   *   The approver's UID.
   */
  public function getApproverId(): int;

  /**
   * Gets the label for an approver (the username).
   *
   * @return string|null
   *   The username string.
   */
  public function getApproverLabel(): ?string;

  /**
   * Gets the label for an owner (the username).
   *
   * @return string|null
   *   The username string.
   */
  public function getOwnerLabel(): ?string;

  /**
   * Gets the assigner's UID from the request.
   *
   * @return int
   *   The assigner's UID.
   */
  public function getAssignerId(): int;

  /**
   * Gets the content entity id from the request.
   *
   * @return int
   *   The ID of the content entity this moderation state is for.
   */
  public function getContentEntityId(): int;

  /**
   * Gets the content entity revision id from the request.
   *
   * @return int
   *   The revision ID of the content entity this moderation state is for.
   */
  public function getContentEntityRevisionId(): int;

  /**
   * Gets the label for an assigner (the username).
   *
   * @return string
   *   The username string.
   */
  public function getAssignerLabel();

  /**
   * Gets the entity revision that the approval request is for.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface|null
   *   The parent entity of the approval request.
   */
  public function getApprovalRevision();

}

==> workbench_approver-1.0.1.tar.gz: workbench_approver/src/Entity/ApproverInterface.php <==
<?php

namespace Drupal\workbench_approver\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\user\EntityOwnerInterface;

/**
 * An interface for the Workbench Approver entity.
 *
 * Workbench Approver entities track required reviewers before content may
 * transition to a new state.
 *
 * Note also that the word 'status' is used for approvals, since the
 * word 'state' is reserved for workflows.
 */
interface ApproverInterface extends ContentEntityInterface, EntityOwnerInterface {

  /**
   * Denotes an approval request was removed by an admin.
   */
  const APPROVAL_RESCINDED = 0;

  /**
   * Denotes an approval request has been invalidated.
   *
   * This state can occur due to the rejection of the revision
   * by another approver.
   */
  const APPROVAL_INVALIDATED = 1;

  /**
   * Denotes an approval request has been outdated.
   *
   * This state can occur due to a revision on the parent node.
   */
  const APPROVAL_OUTDATED = 2;

  /**
   * Denotes an approval request has not been fulfilled.
   */
  const APPROVAL_PENDING = 10;

  /**
   * Denotes an approval request has been granted.
   */
  const APPROVAL_GRANTED = 11;

  /**
   * Denotes an approval request has been rejected.
   */
  const APPROVAL_REJECTED = 12;

  /**
   * Mapping array of approval statuses.
   *
   * @todo This might move to the manager service.
   * If it does, so will statusName() and statusValue().
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup[]
   *   An array of statuses, key by integer value, with
   *   translatable markup as values.
   */
  public static function statusList(): array;

  /**
   * Return the human-readable string for a status name.
   *
   * Note that this is a generic lookup, not tied to an
   * entity. For an entity value, use getStatusName().
   *
   * @param int $status
   *   The status value.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The translatable name of the status.
   */
  public static function statusName(int $status): TranslatableMarkup;

  /**
   * Return the storage value for a status name.
   *
   * Note that this is a generic lookup, not tied to an
   * entity. For an entity value, use getStatus().
   *
   * @param string $status
   *   The human-readable name of the status (untranslated).
   *
   * @return int
   *   The status value.
   */
  public static function statusValue(string $status): int;

  /**
   * Get the status of an approval.
   *
   * @return int
   *   The status value.
   */
  public function getStatus(): int;

  /**
   * Get the human-readable status of an approval.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The translated human-readable status value.
   */
  public function getStatusName(): TranslatableMarkup;

  /**
   * Indicates that an approver has a "blocking" status.
   *
   * A blocking approval request is defined as:
   *
   * - ApproverInterface::isRequired() === TRUE
   *
   * AND one of the following:
   * - ApproverInterface::getStatus() === ApproverInterface::APPROVAL_PENDING
   * - ApproverInterface::getStatus() === ApproverInterface::APPROVAL_REJECTED
   *
   * @return bool
   *   Indicates blocking or non-blocking status.
   */
  public function isBlocking(): bool;

  /**
   * Indicates that an approval request has a "pending" status.
   *
   * A pending approval request is defined as:
   *
   * - ApproverInterface::getStatus() === ApproverInterface::APPROVAL_PENDING
   *
   * @return bool
   *   Indicates pending or not pending status.
   */
  public function isPending(): bool;

  /**
   * Indicates that an approval request has a "rejected" status.
   *
   * A rejected approval request is defined as:
   *
   * - ApproverInterface::getStatus() === ApproverInterface::APPROVAL_REJECTED
   *
   * @return bool
   *   Indicates rejected or not rejected status.
   */
  public function isRejected(): bool;

  /**
   * Indicates if the approval is required or not required.
   *
   * It can also be called blocking (required) or non-blocking (not required).
   *
   * @return bool
   *   Indicates required or not required request.
   */
  public function isRequired(): bool;

  /**
   * Requests can be Active or Inactive.
   *
   * When a request is active, it will have a value equal or greater than 10.
   * When a request is inactive, it will have a value lower than 10.
   * 10 corresponds to APPROVAL_PENDING value.
   *
   * @return bool
   *   Indicated if the approval request is active or inactive.
   */
  public function isActive(): bool;

  /**
   * Gets the approver UID from the request.
   *
   * @return int
   *   The approver's UID.
   */
  public function getApproverId(): int;

  /**
   * Gets the label for an approver (the username).
   *
   * @return string|null
   *   The username string.
   */
  public function getApproverLabel(): ?string;

  /**
   * Gets the label for an owner (the username).
   *
   * @return string|null
   *   The username string.
   */
  public function getOwnerLabel(): ?string;

  /**
   * Gets the assigner's UID from the request.
   *
   * @return int
   *   The assigner's UID.
   */
  public function getAssignerId(): int;

  /**
   * Gets the content entity id from the request.
   *
   * @return int
   *   The ID of the content entity this moderation state is for.
   */
  public function getContentEntityId(): int;

  /**
   * Gets the content entity revision id from the request.
   *
   * @return int
   *   The revision ID of the content entity this moderation state is for.
   */
  public function getContentEntityRevisionId(): int;

  /**
   * Gets the label for an assigner (the username).
   *
   * @return string
   *   The username string.
   */
  public function getAssignerLabel();

  /**
   * Gets the entity revision that the approval request is for.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface|null
   *   The parent entity of the approval request.
   */
  public function getApprovalRevision();

}
